PhantomContravariant

Struct PhantomContravariant 

pub struct PhantomContravariant<T>(/* private fields */)
where
    T: ?Sized;
๐Ÿ”ฌThis is a nightly-only experimental API. (phantom_variance_markers #135806)
Zero-sized type used to mark a type parameter as contravariant.

Types passed as arguments to a function are contravariant. If the type is also part of the return value from a function then it is invariant. See the reference for more information.

Note: If T is otherwise covariant or invariant, the resulting type is invariant.

Layout

For all T, the following are guaranteed:

  • size_of::<PhantomContravariant<T>>() == 0
  • align_of::<PhantomContravariant<T>>() == 1

Implementations

Source

impl<T> PhantomContravariant<T>
where T: ?Sized,

pub const fn new() -> Self

๐Ÿ”ฌThis is a nightly-only experimental API. (phantom_variance_markers #135806)

Constructs a new instance of the variance marker.