PhantomContravariantLifetime

Struct PhantomContravariantLifetime 

pub struct PhantomContravariantLifetime<'a>(/* private fields */);
๐Ÿ”ฌThis is a nightly-only experimental API. (phantom_variance_markers #135806)
Zero-sized type used to mark a lifetime as contravariant.

Contravariant lifetimes must live at most as long as declared. See the reference for more information.

Note: If 'a is otherwise covariant or invariant, the resulting type is invariant.

Layout

For all 'a, the following are guaranteed:

  • size_of::<PhantomContravariantLifetime<'a>>() == 0
  • align_of::<PhantomContravariantLifetime<'a>>() == 1

Implementations

Source

impl PhantomContravariantLifetime<'_>

pub const fn new() -> Self

๐Ÿ”ฌThis is a nightly-only experimental API. (phantom_variance_markers #135806)

Constructs a new instance of the variance marker.