pub struct PhantomInvariant<T>(/* private fields */)
where
T: ?Sized;๐ฌThis is a nightly-only experimental API. (
phantom_variance_markers #135806)Expand description
Zero-sized type used to mark a type parameter as invariant.
Types that are both passed as an argument and used as part of the return value from a function are invariant. See the reference for more information.
Layout
For all T, the following are guaranteed:
size_of::<PhantomInvariant<T>>() == 0align_of::<PhantomInvariant<T>>() == 1
Implementations