pub struct PhantomInvariantLifetime<'a>(/* private fields */);๐ฌThis is a nightly-only experimental API. (
phantom_variance_markers #135806)Expand description
Zero-sized type used to mark a lifetime as invariant.
Invariant lifetimes must be live for the exact length declared, neither shorter nor longer. See the reference for more information.
Layout
For all 'a, the following are guaranteed:
size_of::<PhantomInvariantLifetime<'a>>() == 0align_of::<PhantomInvariantLifetime<'a>>() == 1
Implementations